*************************************************
  Pygame CE Logos Page
*************************************************

Pygame CE Logos
===============

These logos are available for use in your own game projects.
Please put them up wherever you see fit.

The pygame-ce logo and its variants were created by Mega-JC and kadir014 on June 30, 2024.

.. container:: fullwidth

    .. image:: _static/pygame_ce_logo.png

    | `pygame_ce_logo.svg <_static/pygame_ce_logo.svg>`_
    | `pygame_ce_logo.png <_static/pygame_ce_logo.png>`_ - 1560 x 800

    .. image:: _static/pygame_ce_lofi.png

    | `pygame_ce_lofi.svg <_static/pygame_ce_lofi.svg>`_
    | `pygame_ce_lofi.png <_static/pygame_ce_lofi.png>`_ - 1560 x 800

    .. image:: _static/pygame_ce_powered.png

    | `pygame_ce_powered.svg <_static/pygame_ce_powered.svg>`_
    | `pygame_ce_powered.png <_static/pygame_ce_powered.png>`_ - 1560 x 824

    .. image:: _static/pygame_ce_tiny.png

    | `pygame_ce_tiny.png <_static/pygame_ce_tiny.png>`_ - 214 x 110

    .. image:: _static/pygame_ce_powered_lowres.png

    | `pygame_ce_powered_lowres.png <_static/pygame_ce_powered_lowres.png>`_ - 101 x 53



Upstream & legacy logos
-----------------------

The pygame logo was originally created
by TheCorruptor on July 29, 2001.

It was upscaled alongside its "LoFi" and "Powered" variants by Mega-JC on
August 29, 2021.

.. container:: fullwidth

  |  `upstream_logos.zip <_static/upstream_logos.zip>`_ - 699 KB

There is a higher resolution layered photoshop image
available `here <https://www.pygame.org/ftp/pygame_ce_logo.psd>`_. *(1.3 MB)*

.. container:: fullwidth

  |  `legacy_logos.zip <_static/legacy_logos.zip>`_ - 50.1 KB
